{% load workon %}<div class="{{ field.classes }} {{ classes.label }}">
    {% if field|is_checkbox_select_multiple %}
        {% include "workon/forms/fields/__label.html" %}
        {% include 'workon/forms/fields/__help_and_errors.html' %}
        <div class="{{ classes.value }}">
            {% for choice in field %}
                  <p>
                    {{ choice.tag }}
                    <label for="{{ choice.auto_id }}">{{ choice.choice_label }}</label>
                  </p>
            {% endfor %}
        </div>

    {% else %}
        {% include "workon/forms/fields/__label.html" %}
        {% include 'workon/forms/fields/__help_and_errors.html' %}
        {{ field }}
    {% endif %}

</div>